@@ -289,7 +289,7 @@ def run_cat_report(output_dir, ticker, df):
     writer.close()
         
 
-def create_chart(workbook, sheet_name, sheet_cols, npd_col, measure, measure_label, x_axis, num_rows, r_squared):
+def create_chart(workbook, sheet_name, sheet_cols, npd_col, measure, measure_label, x_axis, num_rows, r):
 
     npd_col_name = "Total NPD" if npd_col == "total_dollars" else npd_col
     chart = workbook.add_chart({"type":"line"})
@@ -298,10 +298,11 @@ def create_chart(workbook, sheet_name, sheet_cols, npd_col, measure, measure_lab
     chart.set_y_axis({"crossing":"min"})
     chart.set_x_axis({"name":"For Quarter Ending", "position_axis":"on_tick"})
     if npd_col == "total_dollars":
-        chart.set_title({"name":"YY Total NPD {measure} Correlation\nr{superscript} = {r_squared}".format(measure=measure_label.replace("Reported ", ""), superscript=chr(0x00b2), r_squared=round(r_squared, 3))})
+        chart.set_title({"name":"YY Total NPD {measure} Correlation\nr = {r}".format(measure=measure_label.replace("Reported ", ""), r=round(r, 3))})
     elif npd_col in ["BEST_SALES","BEST_EPS"]:
-        chart.set_title({"name":"YY Consensus {measure} Correlation\nr{superscript} = {r_squared}".format(measure=measure_label.replace("Reported ", ""), superscript=chr(0x00b2), r_squared=round(r_squared, 3))})
+        chart.set_title({"name":"YY Consensus {measure} Correlation\nr = {r}".format(measure=measure_label.replace("Reported ", ""), r=round(r, 3))})
     else:
-        chart.set_title({"name":"YY Category {measure} Correlation\nr{superscript} = {r_squared}".format(measure=measure_label.replace("Reported ", ""), superscript=chr(0x00b2), r_squared=round(r_squared, 3))})
+        chart.set_title({"name":"YY Category {measure} Correlation\nr = {r}".format(measure=measure_label.replace("Reported ", ""), r=round(r, 3))})
     chart.set_legend({"position":"bottom"})
+    chart.set_plotarea({"layout":{"x":0.16,"y":0.23,"width":0.84, "height":0.38}})
     return chart
\ No newline at end of file
